/* AisleRiot - statistics.h
 * Copyright (C) 2003 Callum McKenzie <callum@physics.otago.ac.nz>
 *
 * This game is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 */

#ifndef STATISTICS_H
#define STATISTICS_H

G_BEGIN_DECLS

#include <glib.h>

#define STATISTICS_KEY "/apps/aisleriot/statistics"

void show_statistics_dialog (void);
void update_statistics_display (void);
void update_statistics (gboolean won, guint time);
void load_statistics (void);

G_END_DECLS

#endif /* STATISTICS_H */
